==> pmml-model-1.1.3-sources.jar: org/dmg/pmml/MultivariateStat.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import com.sun.xml.bind.Locatable;
import com.sun.xml.bind.annotation.XmlLocation;
import org.jpmml.schema.Added;
import org.jpmml.schema.Version;
import org.xml.sax.Locator;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="category" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="exponent" type="{http://www.dmg.org/PMML-4_2}INT-NUMBER" default="1" />
 *       &lt;attribute name="isIntercept" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       &lt;attribute name="importance" type="{http://www.dmg.org/PMML-4_2}PROB-NUMBER" />
 *       &lt;attribute name="stdError" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="tValue" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="chiSquareValue" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="fStatistic" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="dF" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="pValueAlpha" type="{http://www.dmg.org/PMML-4_2}PROB-NUMBER" />
 *       &lt;attribute name="pValueInitial" type="{http://www.dmg.org/PMML-4_2}PROB-NUMBER" />
 *       &lt;attribute name="pValueFinal" type="{http://www.dmg.org/PMML-4_2}PROB-NUMBER" />
 *       &lt;attribute name="confidenceLevel" type="{http://www.dmg.org/PMML-4_2}PROB-NUMBER" default="0.95" />
 *       &lt;attribute name="confidenceLowerBound" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="confidenceUpperBound" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "MultivariateStat")
@Added(Version.PMML_4_1)
public class MultivariateStat
    extends PMMLObject
    implements Locatable, HasExtensions
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlAttribute(name = "name")
    protected String name;
    @XmlAttribute(name = "category")
    protected String category;
    @XmlAttribute(name = "exponent")
    protected Integer exponent;
    @XmlAttribute(name = "isIntercept")
    protected Boolean intercept;
    @XmlAttribute(name = "importance")
    protected Double importance;
    @XmlAttribute(name = "stdError")
    protected Double stdError;
    @XmlAttribute(name = "tValue")
    protected Double tValue;
    @XmlAttribute(name = "chiSquareValue")
    protected Double chiSquareValue;
    @XmlAttribute(name = "fStatistic")
    protected Double fStatistic;
    @XmlAttribute(name = "dF")
    protected Double df;
    @XmlAttribute(name = "pValueAlpha")
    protected Double pValueAlpha;
    @XmlAttribute(name = "pValueInitial")
    protected Double pValueInitial;
    @XmlAttribute(name = "pValueFinal")
    protected Double pValueFinal;
    @XmlAttribute(name = "confidenceLevel")
    protected Double confidenceLevel;
    @XmlAttribute(name = "confidenceLowerBound")
    protected Double confidenceLowerBound;
    @XmlAttribute(name = "confidenceUpperBound")
    protected Double confidenceUpperBound;
    @XmlLocation
    @XmlTransient
    protected Locator locator;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the name property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the value of the name property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

    /**
     * Gets the value of the category property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCategory() {
        return category;
    }

    /**
     * Sets the value of the category property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCategory(String value) {
        this.category = value;
    }

    /**
     * Gets the value of the exponent property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getExponent() {
        if (exponent == null) {
            return  1;
        } else {
            return exponent;
        }
    }

    /**
     * Sets the value of the exponent property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setExponent(Integer value) {
        this.exponent = value;
    }

    /**
     * Gets the value of the intercept property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIntercept() {
        if (intercept == null) {
            return false;
        } else {
            return intercept;
        }
    }

    /**
     * Sets the value of the intercept property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIntercept(Boolean value) {
        this.intercept = value;
    }

    /**
     * Gets the value of the importance property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getImportance() {
        return importance;
    }

    /**
     * Sets the value of the importance property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setImportance(Double value) {
        this.importance = value;
    }

    /**
     * Gets the value of the stdError property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getStdError() {
        return stdError;
    }

    /**
     * Sets the value of the stdError property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setStdError(Double value) {
        this.stdError = value;
    }

    /**
     * Gets the value of the tValue property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getTValue() {
        return tValue;
    }

    /**
     * Sets the value of the tValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setTValue(Double value) {
        this.tValue = value;
    }

    /**
     * Gets the value of the chiSquareValue property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getChiSquareValue() {
        return chiSquareValue;
    }

    /**
     * Sets the value of the chiSquareValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setChiSquareValue(Double value) {
        this.chiSquareValue = value;
    }

    /**
     * Gets the value of the fStatistic property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getFStatistic() {
        return fStatistic;
    }

    /**
     * Sets the value of the fStatistic property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setFStatistic(Double value) {
        this.fStatistic = value;
    }

    /**
     * Gets the value of the df property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getDF() {
        return df;
    }

    /**
     * Sets the value of the df property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setDF(Double value) {
        this.df = value;
    }

    /**
     * Gets the value of the pValueAlpha property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getPValueAlpha() {
        return pValueAlpha;
    }

    /**
     * Sets the value of the pValueAlpha property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setPValueAlpha(Double value) {
        this.pValueAlpha = value;
    }

    /**
     * Gets the value of the pValueInitial property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getPValueInitial() {
        return pValueInitial;
    }

    /**
     * Sets the value of the pValueInitial property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setPValueInitial(Double value) {
        this.pValueInitial = value;
    }

    /**
     * Gets the value of the pValueFinal property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getPValueFinal() {
        return pValueFinal;
    }

    /**
     * Sets the value of the pValueFinal property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setPValueFinal(Double value) {
        this.pValueFinal = value;
    }

    /**
     * Gets the value of the confidenceLevel property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public double getConfidenceLevel() {
        if (confidenceLevel == null) {
            return  0.95D;
        } else {
            return confidenceLevel;
        }
    }

    /**
     * Sets the value of the confidenceLevel property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setConfidenceLevel(Double value) {
        this.confidenceLevel = value;
    }

    /**
     * Gets the value of the confidenceLowerBound property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getConfidenceLowerBound() {
        return confidenceLowerBound;
    }

    /**
     * Sets the value of the confidenceLowerBound property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setConfidenceLowerBound(Double value) {
        this.confidenceLowerBound = value;
    }

    /**
     * Gets the value of the confidenceUpperBound property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getConfidenceUpperBound() {
        return confidenceUpperBound;
    }

    /**
     * Sets the value of the confidenceUpperBound property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setConfidenceUpperBound(Double value) {
        this.confidenceUpperBound = value;
    }

    public MultivariateStat withExtensions(Extension... values) {
        if (values!= null) {
            for (Extension value: values) {
                getExtensions().add(value);
            }
        }
        return this;
    }

    public MultivariateStat withExtensions(Collection<Extension> values) {
        if (values!= null) {
            getExtensions().addAll(values);
        }
        return this;
    }

    public MultivariateStat withName(String value) {
        setName(value);
        return this;
    }

    public MultivariateStat withCategory(String value) {
        setCategory(value);
        return this;
    }

    public MultivariateStat withExponent(Integer value) {
        setExponent(value);
        return this;
    }

    public MultivariateStat withIntercept(Boolean value) {
        setIntercept(value);
        return this;
    }

    public MultivariateStat withImportance(Double value) {
        setImportance(value);
        return this;
    }

    public MultivariateStat withStdError(Double value) {
        setStdError(value);
        return this;
    }

    public MultivariateStat withTValue(Double value) {
        setTValue(value);
        return this;
    }

    public MultivariateStat withChiSquareValue(Double value) {
        setChiSquareValue(value);
        return this;
    }

    public MultivariateStat withFStatistic(Double value) {
        setFStatistic(value);
        return this;
    }

    public MultivariateStat withDF(Double value) {
        setDF(value);
        return this;
    }

    public MultivariateStat withPValueAlpha(Double value) {
        setPValueAlpha(value);
        return this;
    }

    public MultivariateStat withPValueInitial(Double value) {
        setPValueInitial(value);
        return this;
    }

    public MultivariateStat withPValueFinal(Double value) {
        setPValueFinal(value);
        return this;
    }

    public MultivariateStat withConfidenceLevel(Double value) {
        setConfidenceLevel(value);
        return this;
    }

    public MultivariateStat withConfidenceLowerBound(Double value) {
        setConfidenceLowerBound(value);
        return this;
    }

    public MultivariateStat withConfidenceUpperBound(Double value) {
        setConfidenceUpperBound(value);
        return this;
    }

    public Locator sourceLocation() {
        return locator;
    }

    public void setSourceLocation(Locator newLocator) {
        locator = newLocator;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        for (int i = 0; (((status == VisitorAction.CONTINUE)&&(this.extensions!= null))&&(i<this.extensions.size())); i ++) {
            status = this.extensions.get(i).accept(visitor);
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-1.1.8-sources.jar: org/dmg/pmml/MultivariateStat.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.sun.xml.bind.Locatable;
import com.sun.xml.bind.annotation.XmlLocation;
import org.jpmml.schema.Added;
import org.jpmml.schema.Version;
import org.xml.sax.Locator;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="category" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="exponent" type="{http://www.dmg.org/PMML-4_2}INT-NUMBER" default="1" />
 *       &lt;attribute name="isIntercept" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       &lt;attribute name="importance" type="{http://www.dmg.org/PMML-4_2}PROB-NUMBER" />
 *       &lt;attribute name="stdError" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="tValue" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="chiSquareValue" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="fStatistic" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="dF" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="pValueAlpha" type="{http://www.dmg.org/PMML-4_2}PROB-NUMBER" />
 *       &lt;attribute name="pValueInitial" type="{http://www.dmg.org/PMML-4_2}PROB-NUMBER" />
 *       &lt;attribute name="pValueFinal" type="{http://www.dmg.org/PMML-4_2}PROB-NUMBER" />
 *       &lt;attribute name="confidenceLevel" type="{http://www.dmg.org/PMML-4_2}PROB-NUMBER" default="0.95" />
 *       &lt;attribute name="confidenceLowerBound" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="confidenceUpperBound" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "MultivariateStat", namespace = "http://www.dmg.org/PMML-4_2")
@Added(Version.PMML_4_1)
public class MultivariateStat
    extends PMMLObject
    implements Locatable, HasExtensions
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_2")
    protected List<Extension> extensions;
    @XmlAttribute(name = "name")
    protected String name;
    @XmlAttribute(name = "category")
    protected String category;
    @XmlAttribute(name = "exponent")
    @XmlJavaTypeAdapter(IntegerAdapter.class)
    protected Integer exponent;
    @XmlAttribute(name = "isIntercept")
    protected Boolean intercept;
    @XmlAttribute(name = "importance")
    @XmlJavaTypeAdapter(DecimalAdapter.class)
    protected Double importance;
    @XmlAttribute(name = "stdError")
    protected Double stdError;
    @XmlAttribute(name = "tValue")
    protected Double tValue;
    @XmlAttribute(name = "chiSquareValue")
    protected Double chiSquareValue;
    @XmlAttribute(name = "fStatistic")
    protected Double fStatistic;
    @XmlAttribute(name = "dF")
    protected Double df;
    @XmlAttribute(name = "pValueAlpha")
    @XmlJavaTypeAdapter(DecimalAdapter.class)
    protected Double pValueAlpha;
    @XmlAttribute(name = "pValueInitial")
    @XmlJavaTypeAdapter(DecimalAdapter.class)
    protected Double pValueInitial;
    @XmlAttribute(name = "pValueFinal")
    @XmlJavaTypeAdapter(DecimalAdapter.class)
    protected Double pValueFinal;
    @XmlAttribute(name = "confidenceLevel")
    @XmlJavaTypeAdapter(DecimalAdapter.class)
    protected Double confidenceLevel;
    @XmlAttribute(name = "confidenceLowerBound")
    protected Double confidenceLowerBound;
    @XmlAttribute(name = "confidenceUpperBound")
    protected Double confidenceUpperBound;
    @XmlLocation
    @XmlTransient
    protected Locator locator;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the name property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the value of the name property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

    /**
     * Gets the value of the category property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCategory() {
        return category;
    }

    /**
     * Sets the value of the category property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCategory(String value) {
        this.category = value;
    }

    /**
     * Gets the value of the exponent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public int getExponent() {
        if (exponent == null) {
            return new IntegerAdapter().unmarshal("1");
        } else {
            return exponent;
        }
    }

    /**
     * Sets the value of the exponent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setExponent(Integer value) {
        this.exponent = value;
    }

    /**
     * Gets the value of the intercept property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIntercept() {
        if (intercept == null) {
            return false;
        } else {
            return intercept;
        }
    }

    /**
     * Sets the value of the intercept property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIntercept(Boolean value) {
        this.intercept = value;
    }

    /**
     * Gets the value of the importance property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Double getImportance() {
        return importance;
    }

    /**
     * Sets the value of the importance property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setImportance(Double value) {
        this.importance = value;
    }

    /**
     * Gets the value of the stdError property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getStdError() {
        return stdError;
    }

    /**
     * Sets the value of the stdError property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setStdError(Double value) {
        this.stdError = value;
    }

    /**
     * Gets the value of the tValue property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getTValue() {
        return tValue;
    }

    /**
     * Sets the value of the tValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setTValue(Double value) {
        this.tValue = value;
    }

    /**
     * Gets the value of the chiSquareValue property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getChiSquareValue() {
        return chiSquareValue;
    }

    /**
     * Sets the value of the chiSquareValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setChiSquareValue(Double value) {
        this.chiSquareValue = value;
    }

    /**
     * Gets the value of the fStatistic property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getFStatistic() {
        return fStatistic;
    }

    /**
     * Sets the value of the fStatistic property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setFStatistic(Double value) {
        this.fStatistic = value;
    }

    /**
     * Gets the value of the df property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getDF() {
        return df;
    }

    /**
     * Sets the value of the df property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setDF(Double value) {
        this.df = value;
    }

    /**
     * Gets the value of the pValueAlpha property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Double getPValueAlpha() {
        return pValueAlpha;
    }

    /**
     * Sets the value of the pValueAlpha property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPValueAlpha(Double value) {
        this.pValueAlpha = value;
    }

    /**
     * Gets the value of the pValueInitial property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Double getPValueInitial() {
        return pValueInitial;
    }

    /**
     * Sets the value of the pValueInitial property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPValueInitial(Double value) {
        this.pValueInitial = value;
    }

    /**
     * Gets the value of the pValueFinal property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Double getPValueFinal() {
        return pValueFinal;
    }

    /**
     * Sets the value of the pValueFinal property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPValueFinal(Double value) {
        this.pValueFinal = value;
    }

    /**
     * Gets the value of the confidenceLevel property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public double getConfidenceLevel() {
        if (confidenceLevel == null) {
            return new DecimalAdapter().unmarshal("0.95");
        } else {
            return confidenceLevel;
        }
    }

    /**
     * Sets the value of the confidenceLevel property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfidenceLevel(Double value) {
        this.confidenceLevel = value;
    }

    /**
     * Gets the value of the confidenceLowerBound property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getConfidenceLowerBound() {
        return confidenceLowerBound;
    }

    /**
     * Sets the value of the confidenceLowerBound property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setConfidenceLowerBound(Double value) {
        this.confidenceLowerBound = value;
    }

    /**
     * Gets the value of the confidenceUpperBound property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getConfidenceUpperBound() {
        return confidenceUpperBound;
    }

    /**
     * Sets the value of the confidenceUpperBound property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setConfidenceUpperBound(Double value) {
        this.confidenceUpperBound = value;
    }

    public MultivariateStat withExtensions(Extension... values) {
        if (values!= null) {
            for (Extension value: values) {
                getExtensions().add(value);
            }
        }
        return this;
    }

    public MultivariateStat withExtensions(Collection<Extension> values) {
        if (values!= null) {
            getExtensions().addAll(values);
        }
        return this;
    }

    public MultivariateStat withName(String value) {
        setName(value);
        return this;
    }

    public MultivariateStat withCategory(String value) {
        setCategory(value);
        return this;
    }

    public MultivariateStat withExponent(Integer value) {
        setExponent(value);
        return this;
    }

    public MultivariateStat withIntercept(Boolean value) {
        setIntercept(value);
        return this;
    }

    public MultivariateStat withImportance(Double value) {
        setImportance(value);
        return this;
    }

    public MultivariateStat withStdError(Double value) {
        setStdError(value);
        return this;
    }

    public MultivariateStat withTValue(Double value) {
        setTValue(value);
        return this;
    }

    public MultivariateStat withChiSquareValue(Double value) {
        setChiSquareValue(value);
        return this;
    }

    public MultivariateStat withFStatistic(Double value) {
        setFStatistic(value);
        return this;
    }

    public MultivariateStat withDF(Double value) {
        setDF(value);
        return this;
    }

    public MultivariateStat withPValueAlpha(Double value) {
        setPValueAlpha(value);
        return this;
    }

    public MultivariateStat withPValueInitial(Double value) {
        setPValueInitial(value);
        return this;
    }

    public MultivariateStat withPValueFinal(Double value) {
        setPValueFinal(value);
        return this;
    }

    public MultivariateStat withConfidenceLevel(Double value) {
        setConfidenceLevel(value);
        return this;
    }

    public MultivariateStat withConfidenceLowerBound(Double value) {
        setConfidenceLowerBound(value);
        return this;
    }

    public MultivariateStat withConfidenceUpperBound(Double value) {
        setConfidenceUpperBound(value);
        return this;
    }

    public Locator sourceLocation() {
        return locator;
    }

    public void setSourceLocation(Locator newLocator) {
        locator = newLocator;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        for (int i = 0; (((status == VisitorAction.CONTINUE)&&(this.extensions!= null))&&(i<this.extensions.size())); i ++) {
            status = this.extensions.get(i).accept(visitor);
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
